abacusai.api_class.ai_chat — AbacusAI documentation

# abacusai.api_class.ai_chat

## Classes

`HotkeyPrompt` | A config class for a Data Science Co-Pilot Hotkey
`AgentConversationMessage` | Message format for agent conversation

## Module Contents

class abacusai.api_class.ai_chat.HotkeyPrompt

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for a Data Science Co-Pilot Hotkey

  Parameters:

    - prompt (str) – The prompt to send to Data Science Co-Pilot

    - title (str) – A short, descriptive title for the prompt. If not provided, one will be automatically generated.

  prompt: str
  title: str
  disable_problem_type_context: bool
  ignore_history: bool

class abacusai.api_class.ai_chat.AgentConversationMessage

  Bases: `abacusai.api_class.abstract.ApiClass`

  Message format for agent conversation

  Parameters:

    - is_user (bool) – Whether the message is from the user.

    - text (str) – The message’s text.

    - document_content (str) – Document text in case of any document present.

  is_user: bool
  text: str
  document_content: str
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.